==> calamares-settings-solydxk_4.12%2Br13.tar.xz: source/ts/calamares-solydxk_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Obrigado por escolher a SolydXK.&lt;/h3&gt;&lt;br /&gt;Escolheu uma distribuição Linux que é:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Segura e estável&lt;/li&gt;&lt;li&gt;Rápida e responsiva&lt;/li&gt;&lt;li&gt;Uma área de trabalho pronta&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Aproveite este novo lançamento e obrigado por escolher a SolydXK.&lt;br /&gt;&lt;br /&gt;A instalação tem uma duração de 15-30 minutos, dependendo das suas configurações.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Em cima dos ombros de Gigantes&lt;/h3&gt;&lt;br /&gt;SolydXK é uma distribuição GNU/Linux, derivado e compatível com Debian.&lt;br /&gt;&lt;br /&gt;SolydXK usa tanto o leve ambiente de trabalho Xfce para o SolydX ou o altamente configurável e tão atraente ambiente de trabalho KDE para o SolydK.&lt;br /&gt;&lt;br /&gt;As nossas inovações, o rápido desenvolvimento do Debian e a enorme selecção de pacotes Debian fazem da SolydXK uma dos mais atraentes sistemas operativos de ambiente de trabalho disponíveis para utilizadores domésticos.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Pronto a usar&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, e LibreOffice vêm pré-instalados em SolydXK, para que possa começar imediatamente com o ambiente de trabalho e na Internet.&lt;br /&gt;&lt;br /&gt;Ao contrário de outras distribuições de Linux, SolydXK também está pronto para tocar a sua música, vídeos na Internet e muito mais.&lt;br /&gt;&lt;br /&gt;Uma grande variedade de software poderá ser instalado com um clique do rato.&lt;br /&gt;&lt;br /&gt;SolydXK é compatível com a maior parte de formatos de ficheiros como os: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, e muito mais.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;As ferramentas de escritório estão prontas a usar assim que instalar SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, um poderoso grupo de software de escritório, vem incluído no SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice é fácil de aprender e de usar.&lt;br /&gt;&lt;br /&gt;Pode usar para criar cartas, apresentações e folhas de cálculo, assim como diagramas e base de dados.&lt;br /&gt;&lt;br /&gt;LibreOffice  utiliza o formato padrão OpenDocument e funciona com documentos de outras aplicações de escritório populares, incluindo WordPerfect e Microsoft Office.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.&lt;br /&gt;&lt;br /&gt;SolydXK can detect other operating systems and install itself beside them.You can choose which operating system to launch when you start the computer.</source>
        <translation>&lt;h3&gt;Uma alternativa aos sistemas operativos convencionais&lt;/h3&gt;&lt;br /&gt;SolydXK é fácil de usar, poderoso e configurável.&lt;br /&gt;&lt;br /&gt;SolydXK é seguro e estável. Ao contrário de outros sistemas operativos, não é propenso a vírus ou spyware, ele não sofre de fragmentação do disco, e não tem nenhum registry que requeira uma limpeza periódica.&lt;br /&gt;&lt;br /&gt;SolydXK pode detectar outros sistemas operativos e instalar-se ao lado deles. Pode escolher qual sistema operativo para iniciar quando você iniciar o computador.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="143"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Actualizações seguras&lt;/h3&gt;&lt;br /&gt;Alguns sistemas operativos fazem da actualização do sistema mais difícil do que realmente precisa ser. SolydXK pensa que as actualizações devem ser rápidas e fáceis, e em seguida sair.&lt;br /&gt;&lt;br /&gt;O Gestor de Actualizações fica discretamente na bandeja do sistema e permite que saiba quando há actualizações disponíveis. Não tem de aplicar as actualizações quando não quer. O Gestor de Actualizações não irá aparecer ou irritá-lo de qualquer forma.&lt;br /&gt;&lt;br /&gt;Todos os ficheiros actualizados serão mantidos e sempre verificados por uma equipa de programadores e manutenção de confiança.&lt;br /&gt;&lt;br /&gt;Todos os ficheiros estão armazenados em repositórios especiais e seguros para o seu uso.&lt;br /&gt;&lt;br /&gt;O repositório de segurança é sincronizado diariamente.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="165"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Uma grande comunidade.&lt;/h3&gt;&lt;br /&gt;Os utilizadores de SolydXK sentem-se bem em compartilhar a sua paixão e entusiasmo e estão ansiosos para o ajudar. Não hesite em fazer perguntas nos fóruns ou envolva-se na comunidade.&lt;br /&gt;&lt;br /&gt;Envie-nos os seus comentários e conte-nos sobre a sua experiência. Iremos ouvir as suas ideias e usá-las para melhorar ainda mais a SolydXK.</translation>
    </message>
</context>
</TS>

==> calamares-settings-solydxk_4.27%2Br13.tar.xz: source/ts/calamares-solydxk_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Obrigado por escolher a SolydXK.&lt;/h3&gt;&lt;br /&gt;Escolheu uma distribuição Linux que é:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Segura e estável&lt;/li&gt;&lt;li&gt;Rápida e responsiva&lt;/li&gt;&lt;li&gt;Uma área de trabalho pronta&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Aproveite este novo lançamento e obrigado por escolher a SolydXK.&lt;br /&gt;&lt;br /&gt;A instalação tem uma duração de 15-30 minutos, dependendo das suas configurações.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Em cima dos ombros de Gigantes&lt;/h3&gt;&lt;br /&gt;SolydXK é uma distribuição GNU/Linux, derivado e compatível com Debian.&lt;br /&gt;&lt;br /&gt;SolydXK usa tanto o leve ambiente de trabalho Xfce para o SolydX ou o altamente configurável e tão atraente ambiente de trabalho KDE para o SolydK.&lt;br /&gt;&lt;br /&gt;As nossas inovações, o rápido desenvolvimento do Debian e a enorme selecção de pacotes Debian fazem da SolydXK uma dos mais atraentes sistemas operativos de ambiente de trabalho disponíveis para utilizadores domésticos.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Pronto a usar&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, e LibreOffice vêm pré-instalados em SolydXK, para que possa começar imediatamente com o ambiente de trabalho e na Internet.&lt;br /&gt;&lt;br /&gt;Ao contrário de outras distribuições de Linux, SolydXK também está pronto para tocar a sua música, vídeos na Internet e muito mais.&lt;br /&gt;&lt;br /&gt;Uma grande variedade de software poderá ser instalado com um clique do rato.&lt;br /&gt;&lt;br /&gt;SolydXK é compatível com a maior parte de formatos de ficheiros como os: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, e muito mais.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;As ferramentas de escritório estão prontas a usar assim que instalar SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, um poderoso grupo de software de escritório, vem incluído no SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice é fácil de aprender e de usar.&lt;br /&gt;&lt;br /&gt;Pode usar para criar cartas, apresentações e folhas de cálculo, assim como diagramas e base de dados.&lt;br /&gt;&lt;br /&gt;LibreOffice  utiliza o formato padrão OpenDocument e funciona com documentos de outras aplicações de escritório populares, incluindo WordPerfect e Microsoft Office.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.</source>
        <translation>&lt;h3&gt;Uma alternativa aos sistemas operativos convencionais&lt;/h3&gt;&lt;br /&gt;SolydXK é fácil de usar, poderoso e configurável.&lt;br /&gt;&lt;br /&gt;SolydXK é seguro e estável. Ao contrário de outros sistemas operativos, não é propenso a vírus ou spyware, ele não sofre de fragmentação do disco, e não tem nenhum registry que requeira uma limpeza periódica.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="142"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Actualizações seguras&lt;/h3&gt;&lt;br /&gt;Alguns sistemas operativos fazem da actualização do sistema mais difícil do que realmente precisa ser. SolydXK pensa que as actualizações devem ser rápidas e fáceis, e em seguida sair.&lt;br /&gt;&lt;br /&gt;O Gestor de Actualizações fica discretamente na bandeja do sistema e permite que saiba quando há actualizações disponíveis. Não tem de aplicar as actualizações quando não quer. O Gestor de Actualizações não irá aparecer ou irritá-lo de qualquer forma.&lt;br /&gt;&lt;br /&gt;Todos os ficheiros actualizados serão mantidos e sempre verificados por uma equipa de programadores e manutenção de confiança.&lt;br /&gt;&lt;br /&gt;Todos os ficheiros estão armazenados em repositórios especiais e seguros para o seu uso.&lt;br /&gt;&lt;br /&gt;O repositório de segurança é sincronizado diariamente.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="164"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Uma grande comunidade.&lt;/h3&gt;&lt;br /&gt;Os utilizadores de SolydXK sentem-se bem em compartilhar a sua paixão e entusiasmo e estão ansiosos para o ajudar. Não hesite em fazer perguntas nos fóruns ou envolva-se na comunidade.&lt;br /&gt;&lt;br /&gt;Envie-nos os seus comentários e conte-nos sobre a sua experiência. Iremos ouvir as suas ideias e usá-las para melhorar ainda mais a SolydXK.</translation>
    </message>
</context>
</TS>
